@@ -1,4 +1,4 @@
-// Copyright 2019 The TCell Authors
+// Copyright 2020 The TCell Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use file except in compliance with the License.
@@ -24,9 +24,9 @@ package base
 import (
 	// The following imports just register themselves --
 	// thse are the terminal types we aggregate in this package.
-	_ "github.com/gdamore/tcell/terminfo/a/ansi"
-	_ "github.com/gdamore/tcell/terminfo/v/vt100"
-	_ "github.com/gdamore/tcell/terminfo/v/vt102"
-	_ "github.com/gdamore/tcell/terminfo/v/vt220"
-	_ "github.com/gdamore/tcell/terminfo/x/xterm"
+	_ "github.com/gdamore/tcell/v2/terminfo/a/ansi"
+	_ "github.com/gdamore/tcell/v2/terminfo/v/vt100"
+	_ "github.com/gdamore/tcell/v2/terminfo/v/vt102"
+	_ "github.com/gdamore/tcell/v2/terminfo/v/vt220"
+	_ "github.com/gdamore/tcell/v2/terminfo/x/xterm"
 )
